@@ -12,12 +12,13 @@ from ipywidgets import Tab
 from cbm.ipycbm.utils import settings, help_docs
 from cbm.ipycbm.ipy_ext import ext_panel
 
+
 def ext_widget_box():
 
     tab_box = Tab(children=[ext_panel.extract(), help_docs.widget_box(),
-                  settings.main()])
+                            settings.main()])
 
-    tab_box.set_title(0, 'Process Data')
+    tab_box.set_title(0, 'Extract Data')
     tab_box.set_title(1, 'Help')
     tab_box.set_title(2, 'Settings')
 
